/// <reference types="node" />
/// <reference types="node" />
import { ReadStream } from "fs-extra";
import { BiliCredential } from "./biliCredential";
import { SignResp, LiveUserInfoResp, StartLiveResp, StopLiveResp, StreamAddrResp, LiveAreaListResp, GetCoverListResp, BaseInfoResp, RoomInfoResp } from "./types/live";
/**
 * 直播间相关
 */
export declare class Live {
    private credential;
    constructor(credential: BiliCredential);
    /**
     * 签到
     * @returns
     */
    sign(): Promise<SignResp>;
    /**
     * 个人信息，直播等级，瓜子电池之类的
     * @returns
     */
    selfInfo(): Promise<LiveUserInfoResp>;
    /**
     * 开播
     * @param area 直播分区代码
     * @param roomid 自己的房间号
     * @returns
     */
    startLive(area: number, roomid?: number): Promise<StartLiveResp>;
    /**
     * 下播
     * @param roomid 自己的房间号
     * @returns
     */
    stopLive(roomid?: number): Promise<StopLiveResp>;
    /**
     * 获取，刷新推流地址
     * @param reset_key 是否刷新推流地址，默认false
     * @returns
     */
    streamAddr(reset_key: false): Promise<StreamAddrResp>;
    /**
     * 主播公告
     * @param content 说说下次开播的时间和内容吧~
     * @returns
     */
    updateRoomNews(content: string): Promise<boolean>;
    /**
     * 修改直播间信息
     * @param content 标签名称
     * @param manipulate 操作内容，标题=title，简介=description，新增标签=add_tag，删除标签=del_tag
     * @returns
     */
    private _update;
    /**
     * 修改房间标题
     * @param title 标题
     * @returns
     */
    updateTitle(title: string): Promise<boolean>;
    /**
     * 修改个人简介
     * @param desc 请输入你的个人简介~
     * @returns
     */
    updateDesc(desc: string): Promise<boolean>;
    /**
     * 更新tag
     * @param tag tag内容
     * @param add_del 新增或删除，默认为true/新增
     * @returns
     */
    updateTag(tag: string, add_del: boolean): Promise<boolean>;
    /**
     * 上传封面
     * @param cover 封面链接/buffer/stream
     * @returns
     */
    private _uploadCover;
    /**
     * 获取最新上传的封面状态，推荐用在updateCover后
     * @returns
     */
    getNewCover(): Promise<GetCoverListResp>;
    /**
     * 获取自己直播间的封面列表
     * @returns 其中audit_status 判断是否过审，0=审核中，1=已过审，-1=没过审
     */
    getCoverList(): Promise<GetCoverListResp[]>;
    /**
     * 修改封面
     * @param cover 图片，最小为960*540 (16:9)，颜值区封面为500*500
     * @param cover_type 普通直播 = cover， 颜值区 = show，默认为普通
     * @returns
     */
    updateCover(cover: string | Buffer | ReadStream, cover_type?: "cover" | "show"): Promise<boolean>;
    /**
     * 获取房间信息
     * @param id 房间号或主播id
     * @param id_type id类型为uid或roomid
     * @returns
     */
    static getRoomBaseInfo(id: number, id_type: "uid" | "roomid"): Promise<BaseInfoResp>;
    /**
     * 获取房间更详细信息
     * @param room_id 房间号
     * @returns
     */
    static getRoomInfo(room_id: number): Promise<RoomInfoResp>;
    /**
     * 获取直播分区列表
     * @returns
     */
    static getAreaList(): Promise<LiveAreaListResp[]>;
}
//# sourceMappingURL=live.d.ts.map